package de.intevation.gnv.transition;

import de.intevation.gnv.state.State;

import java.io.Serializable;

import org.w3c.dom.Node;

/**
 * This interface describes basic methods necessary for a transition model.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public interface Transition extends Serializable{

    /**
     * Returns the ID of the State from which the Transition could be used
     * @return the ID of the State from which the Transition could be used
     */
    public String getFrom();

    /**
     * Returns the ID of the State where it is possible to go as next.
     * @return the ID of the State where it is possible to go as next.
     */
    public String getTo();

    /**
     * Determines if it is possible to go along this Transition or not.
     * @param state the current State
     * @return true, if this transition is valid for the given state - otherwise
     * false.
     */
    public boolean isValid(State state);

    /**
     * Configures the Transition.
     * @param configuration
     */
    public void setup(Node configuration);

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :